"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MfaEnforcementStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MfaEnforcementStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MfaEnforcementStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MFA_ENFORCEMENT_STATUS_UNSPECIFIED: _MfaEnforcementStatus.ValueType  # 0
    MFA_ENFORCEMENT_STATUS_ACTIVE: _MfaEnforcementStatus.ValueType  # 1
    MFA_ENFORCEMENT_STATUS_INACTIVE: _MfaEnforcementStatus.ValueType  # 2
    MFA_ENFORCEMENT_STATUS_DELETING: _MfaEnforcementStatus.ValueType  # 3

class MfaEnforcementStatus(_MfaEnforcementStatus, metaclass=_MfaEnforcementStatusEnumTypeWrapper): ...

MFA_ENFORCEMENT_STATUS_UNSPECIFIED: MfaEnforcementStatus.ValueType  # 0
MFA_ENFORCEMENT_STATUS_ACTIVE: MfaEnforcementStatus.ValueType  # 1
MFA_ENFORCEMENT_STATUS_INACTIVE: MfaEnforcementStatus.ValueType  # 2
MFA_ENFORCEMENT_STATUS_DELETING: MfaEnforcementStatus.ValueType  # 3
global___MfaEnforcementStatus = MfaEnforcementStatus

@typing.final
class MfaEnforcement(google.protobuf.message.Message):
    """MFA enforcement resource"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    ACR_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLY_AT_FIELD_NUMBER: builtins.int
    ENROLL_WINDOW_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """id of the MFA enforcement"""
    organization_id: builtins.str
    """organization id of the MFA enforcement"""
    acr_id: builtins.str
    """acr id of the MFA enforcement"""
    status: global___MfaEnforcementStatus.ValueType
    """MFA enforcement status"""
    name: builtins.str
    """name of the MFA enforcement"""
    description: builtins.str
    """description of the MFA enforcement"""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """the period during which the entered MFA factor is considered valid and the 
        corresponding acr is regarded as satisfied
        """

    @property
    def apply_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the MFA enforcement application start time."""

    @property
    def enroll_window(self) -> google.protobuf.duration_pb2.Duration:
        """the time window during which the user is allowed to create an MFA profile. 
        this window is measured relative to the MFA enforcement application start time
        and the user's most recent successful authentication that falls under the rule 
        (or the user's creation time, if there has been no authentication).
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation timestamp"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        acr_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
        status: global___MfaEnforcementStatus.ValueType = ...,
        apply_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enroll_window: google.protobuf.duration_pb2.Duration | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["apply_at", b"apply_at", "created_at", b"created_at", "enroll_window", b"enroll_window", "ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acr_id", b"acr_id", "apply_at", b"apply_at", "created_at", b"created_at", "description", b"description", "enroll_window", b"enroll_window", "id", b"id", "name", b"name", "organization_id", b"organization_id", "status", b"status", "ttl", b"ttl"]) -> None: ...

global___MfaEnforcement = MfaEnforcement



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_settings_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/idp/synchronization_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SynchronizationServiceStub(object):
    """A set of methods for managing synchronization settings.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetReplicationToken = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/SetReplicationToken',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.SetReplicationTokenRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ResetReplicationToken = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/ResetReplicationToken',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ResetReplicationTokenRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.CreateSynchronizationSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/CreateSynchronizationSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.CreateSynchronizationSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateSynchronizationSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/UpdateSynchronizationSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.UpdateSynchronizationSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DeleteSynchronizationSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/DeleteSynchronizationSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.DeleteSynchronizationSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetSynchronizationSettings = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/GetSynchronizationSettings',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.GetSynchronizationSettingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2.SynchronizationSettings.FromString,
                _registered_method=True)
        self.ListSupportedAttributes = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/ListSupportedAttributes',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesResponse.FromString,
                _registered_method=True)


class SynchronizationServiceServicer(object):
    """A set of methods for managing synchronization settings.
    """

    def SetReplicationToken(self, request, context):
        """Sets the replication token for synchronization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetReplicationToken(self, request, context):
        """Resets the replication token for synchronization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSynchronizationSettings(self, request, context):
        """Creates synchronization settings for a subject container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSynchronizationSettings(self, request, context):
        """Updates synchronization settings for a subject container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSynchronizationSettings(self, request, context):
        """Deletes synchronization settings for a subject container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSynchronizationSettings(self, request, context):
        """Returns synchronization settings for a subject container.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupportedAttributes(self, request, context):
        """Lists supported attributes for synchronization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SynchronizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetReplicationToken': grpc.unary_unary_rpc_method_handler(
                    servicer.SetReplicationToken,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.SetReplicationTokenRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResetReplicationToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetReplicationToken,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ResetReplicationTokenRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CreateSynchronizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSynchronizationSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.CreateSynchronizationSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateSynchronizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSynchronizationSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.UpdateSynchronizationSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteSynchronizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSynchronizationSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.DeleteSynchronizationSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetSynchronizationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSynchronizationSettings,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.GetSynchronizationSettingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2.SynchronizationSettings.SerializeToString,
            ),
            'ListSupportedAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupportedAttributes,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.idp.SynchronizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.idp.SynchronizationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SynchronizationService(object):
    """A set of methods for managing synchronization settings.
    """

    @staticmethod
    def SetReplicationToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/SetReplicationToken',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.SetReplicationTokenRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResetReplicationToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/ResetReplicationToken',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ResetReplicationTokenRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSynchronizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/CreateSynchronizationSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.CreateSynchronizationSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateSynchronizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/UpdateSynchronizationSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.UpdateSynchronizationSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSynchronizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/DeleteSynchronizationSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.DeleteSynchronizationSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSynchronizationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/GetSynchronizationSettings',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.GetSynchronizationSettingsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2.SynchronizationSettings.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSupportedAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.SynchronizationService/ListSupportedAttributes',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__service__pb2.ListSupportedAttributesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TimeGrouping:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TimeGroupingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeGrouping.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TIME_GROUPING_UNSPECIFIED: _TimeGrouping.ValueType  # 0
    """Default unspecified value. Typically treated as DAY."""
    DAY: _TimeGrouping.ValueType  # 1
    """Group reports by day."""
    WEEK: _TimeGrouping.ValueType  # 2
    """Group reports by week."""
    MONTH: _TimeGrouping.ValueType  # 3
    """Group reports by month."""
    QUARTER: _TimeGrouping.ValueType  # 4
    """Group reports by quarter (3-month periods)."""
    YEAR: _TimeGrouping.ValueType  # 5
    """Group reports by year."""

class TimeGrouping(_TimeGrouping, metaclass=_TimeGroupingEnumTypeWrapper):
    """Enum for time period grouping options used to control the granularity of time-based data aggregation.
    This determines how the time series data is grouped in responses (e.g., daily, monthly reports).
    """

TIME_GROUPING_UNSPECIFIED: TimeGrouping.ValueType  # 0
"""Default unspecified value. Typically treated as DAY."""
DAY: TimeGrouping.ValueType  # 1
"""Group reports by day."""
WEEK: TimeGrouping.ValueType  # 2
"""Group reports by week."""
MONTH: TimeGrouping.ValueType  # 3
"""Group reports by month."""
QUARTER: TimeGrouping.ValueType  # 4
"""Group reports by quarter (3-month periods)."""
YEAR: TimeGrouping.ValueType  # 5
"""Group reports by year."""
global___TimeGrouping = TimeGrouping

class _Currency:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CurrencyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Currency.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CURRENCY_UNSPECIFIED: _Currency.ValueType  # 0
    """Unspecified or unknown currency."""
    RUB: _Currency.ValueType  # 1
    """Russian Ruble"""
    USD: _Currency.ValueType  # 2
    """US Dollar"""
    KZT: _Currency.ValueType  # 3
    """Kazakhstani Tenge"""
    EUR: _Currency.ValueType  # 4
    """Euro"""

class Currency(_Currency, metaclass=_CurrencyEnumTypeWrapper):
    """Enum for supported currency codes used in billing and financial reports."""

CURRENCY_UNSPECIFIED: Currency.ValueType  # 0
"""Unspecified or unknown currency."""
RUB: Currency.ValueType  # 1
"""Russian Ruble"""
USD: Currency.ValueType  # 2
"""US Dollar"""
KZT: Currency.ValueType  # 3
"""Kazakhstani Tenge"""
EUR: Currency.ValueType  # 4
"""Euro"""
global___Currency = Currency

@typing.final
class StringDecimal(google.protobuf.message.Message):
    """StringDecimal representation for financial values
    Used to ensure precise handling of monetary values
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """String representation of the decimal value to avoid floating-point precision issues"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["value", b"value"]) -> None: ...

global___StringDecimal = StringDecimal



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Device:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Device.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEVICE_UNSPECIFIED: _Device.ValueType  # 0
    DEVICE_ALL: _Device.ValueType  # 1
    """All devices."""
    DEVICE_DESKTOP: _Device.ValueType  # 2
    """Desktop computers."""
    DEVICE_PHONE: _Device.ValueType  # 3
    """Phones."""
    DEVICE_TABLET: _Device.ValueType  # 4
    """Tablets."""

class Device(_Device, metaclass=_DeviceEnumTypeWrapper): ...

DEVICE_UNSPECIFIED: Device.ValueType  # 0
DEVICE_ALL: Device.ValueType  # 1
"""All devices."""
DEVICE_DESKTOP: Device.ValueType  # 2
"""Desktop computers."""
DEVICE_PHONE: Device.ValueType  # 3
"""Phones."""
DEVICE_TABLET: Device.ValueType  # 4
"""Tablets."""
global___Device = Device

@typing.final
class GetTopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHRASE_FIELD_NUMBER: builtins.int
    NUM_PHRASES_FIELD_NUMBER: builtins.int
    REGIONS_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    phrase: builtins.str
    """Keyword"""
    num_phrases: builtins.int
    """Number of the phrases in the response."""
    folder_id: builtins.str
    """ID of the folder."""
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of IDs of the regions a query was made from."""

    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Device.ValueType]:
        """A list of device types a query was made from."""

    def __init__(
        self,
        *,
        phrase: builtins.str = ...,
        num_phrases: builtins.int = ...,
        regions: collections.abc.Iterable[builtins.str] | None = ...,
        devices: collections.abc.Iterable[global___Device.ValueType] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "folder_id", b"folder_id", "num_phrases", b"num_phrases", "phrase", b"phrase", "regions", b"regions"]) -> None: ...

global___GetTopRequest = GetTopRequest

@typing.final
class GetTopResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PhraseInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PHRASE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        phrase: builtins.str
        """Keyword."""
        count: builtins.int
        """Number of queries made."""
        def __init__(
            self,
            *,
            phrase: builtins.str = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "phrase", b"phrase"]) -> None: ...

    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    ASSOCIATIONS_FIELD_NUMBER: builtins.int
    total_count: builtins.int
    """Total number of the queries that contain all the keywords, regardless of their order."""
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetTopResponse.PhraseInfo]:
        """Results."""

    @property
    def associations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetTopResponse.PhraseInfo]:
        """Queries that are similar to the specified one."""

    def __init__(
        self,
        *,
        total_count: builtins.int = ...,
        results: collections.abc.Iterable[global___GetTopResponse.PhraseInfo] | None = ...,
        associations: collections.abc.Iterable[global___GetTopResponse.PhraseInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["associations", b"associations", "results", b"results", "total_count", b"total_count"]) -> None: ...

global___GetTopResponse = GetTopResponse

@typing.final
class GetDynamicsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Period:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PeriodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetDynamicsRequest._Period.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PERIOD_UNSPECIFIED: GetDynamicsRequest._Period.ValueType  # 0
        PERIOD_MONTHLY: GetDynamicsRequest._Period.ValueType  # 1
        """Details by month."""
        PERIOD_WEEKLY: GetDynamicsRequest._Period.ValueType  # 2
        """Details by week."""
        PERIOD_DAILY: GetDynamicsRequest._Period.ValueType  # 3
        """Details by day."""

    class Period(_Period, metaclass=_PeriodEnumTypeWrapper): ...
    PERIOD_UNSPECIFIED: GetDynamicsRequest.Period.ValueType  # 0
    PERIOD_MONTHLY: GetDynamicsRequest.Period.ValueType  # 1
    """Details by month."""
    PERIOD_WEEKLY: GetDynamicsRequest.Period.ValueType  # 2
    """Details by week."""
    PERIOD_DAILY: GetDynamicsRequest.Period.ValueType  # 3
    """Details by day."""

    PHRASE_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    FROM_DATE_FIELD_NUMBER: builtins.int
    TO_DATE_FIELD_NUMBER: builtins.int
    REGIONS_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    phrase: builtins.str
    """Keyword."""
    period: global___GetDynamicsRequest.Period.ValueType
    """The period of aggregation of the number of queries."""
    folder_id: builtins.str
    """ID of the folder."""
    @property
    def from_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The start of the period data is requested for."""

    @property
    def to_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The end of the period data is requested for."""

    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of IDs of the regions a query was made from."""

    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Device.ValueType]:
        """A list of device types a query was made from."""

    def __init__(
        self,
        *,
        phrase: builtins.str = ...,
        period: global___GetDynamicsRequest.Period.ValueType = ...,
        from_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        regions: collections.abc.Iterable[builtins.str] | None = ...,
        devices: collections.abc.Iterable[global___Device.ValueType] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_date", b"from_date", "to_date", b"to_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "folder_id", b"folder_id", "from_date", b"from_date", "period", b"period", "phrase", b"phrase", "regions", b"regions", "to_date", b"to_date"]) -> None: ...

global___GetDynamicsRequest = GetDynamicsRequest

@typing.final
class GetDynamicsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DynamicsInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        SHARE_FIELD_NUMBER: builtins.int
        count: builtins.int
        """Number of queries containing the given keyword"""
        share: builtins.float
        """The share of the number of such queries from the total number of queries to Yandex."""
        @property
        def date(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """The date"""

        def __init__(
            self,
            *,
            date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            count: builtins.int = ...,
            share: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["date", b"date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "date", b"date", "share", b"share"]) -> None: ...

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetDynamicsResponse.DynamicsInfo]:
        """Results."""

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___GetDynamicsResponse.DynamicsInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["results", b"results"]) -> None: ...

global___GetDynamicsResponse = GetDynamicsResponse

@typing.final
class GetRegionsDistributionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Region:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RegionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetRegionsDistributionRequest._Region.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REGION_UNSPECIFIED: GetRegionsDistributionRequest._Region.ValueType  # 0
        REGION_ALL: GetRegionsDistributionRequest._Region.ValueType  # 1
        """Show distribution everywhere."""
        REGION_CITIES: GetRegionsDistributionRequest._Region.ValueType  # 2
        """Show distribution by cities."""
        REGION_REGIONS: GetRegionsDistributionRequest._Region.ValueType  # 3
        """Show distribution by regions."""

    class Region(_Region, metaclass=_RegionEnumTypeWrapper): ...
    REGION_UNSPECIFIED: GetRegionsDistributionRequest.Region.ValueType  # 0
    REGION_ALL: GetRegionsDistributionRequest.Region.ValueType  # 1
    """Show distribution everywhere."""
    REGION_CITIES: GetRegionsDistributionRequest.Region.ValueType  # 2
    """Show distribution by cities."""
    REGION_REGIONS: GetRegionsDistributionRequest.Region.ValueType  # 3
    """Show distribution by regions."""

    PHRASE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    phrase: builtins.str
    """Keyword"""
    region: global___GetRegionsDistributionRequest.Region.ValueType
    """Show query distribution only by city, only by region, or everywhere."""
    folder_id: builtins.str
    """ID of the folder."""
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Device.ValueType]:
        """A list of device types a query was made from."""

    def __init__(
        self,
        *,
        phrase: builtins.str = ...,
        region: global___GetRegionsDistributionRequest.Region.ValueType = ...,
        devices: collections.abc.Iterable[global___Device.ValueType] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "folder_id", b"folder_id", "phrase", b"phrase", "region", b"region"]) -> None: ...

global___GetRegionsDistributionRequest = GetRegionsDistributionRequest

@typing.final
class GetRegionsDistributionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RegionInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REGION_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        SHARE_FIELD_NUMBER: builtins.int
        AFFINITY_INDEX_FIELD_NUMBER: builtins.int
        region: builtins.str
        """Region ID"""
        count: builtins.int
        """Number of queries containing the given keyword."""
        share: builtins.float
        """The share of the number of such queries from the total number of queries to Yandex in the region."""
        affinity_index: builtins.float
        """The ratio between the share of the selected queries in the region and their share across the country."""
        def __init__(
            self,
            *,
            region: builtins.str = ...,
            count: builtins.int = ...,
            share: builtins.float = ...,
            affinity_index: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["affinity_index", b"affinity_index", "count", b"count", "region", b"region", "share", b"share"]) -> None: ...

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetRegionsDistributionResponse.RegionInfo]:
        """Results."""

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___GetRegionsDistributionResponse.RegionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["results", b"results"]) -> None: ...

global___GetRegionsDistributionResponse = GetRegionsDistributionResponse

@typing.final
class GetRegionsTreeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___GetRegionsTreeRequest = GetRegionsTreeRequest

@typing.final
class GetRegionsTreeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RegionInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        LABEL_FIELD_NUMBER: builtins.int
        CHILDREN_FIELD_NUMBER: builtins.int
        id: builtins.str
        """Region ID."""
        label: builtins.str
        """Region name"""
        @property
        def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetRegionsTreeResponse.RegionInfo]:
            """Child regions."""

        def __init__(
            self,
            *,
            id: builtins.str = ...,
            label: builtins.str = ...,
            children: collections.abc.Iterable[global___GetRegionsTreeResponse.RegionInfo] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["children", b"children", "id", b"id", "label", b"label"]) -> None: ...

    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetRegionsTreeResponse.RegionInfo]:
        """Region tree"""

    def __init__(
        self,
        *,
        regions: collections.abc.Iterable[global___GetRegionsTreeResponse.RegionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["regions", b"regions"]) -> None: ...

global___GetRegionsTreeResponse = GetRegionsTreeResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.billing.usage_records.v1.billing_types_pb2
import yandex.cloud.billing.usage_records.v1.common_types_pb2
import yandex.cloud.billing.usage_records.v1.credit_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BillingAccountUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for the billing account entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the specified billing account across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this billing account."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this billing account."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this billing account."""

    @property
    def billing_account(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.BillingAccount:
        """Metadata for the specified billing account entity."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        billing_account: yandex.cloud.billing.usage_records.v1.billing_types_pb2.BillingAccount | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["billing_account", b"billing_account", "cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account", b"billing_account", "cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "periodic", b"periodic"]) -> None: ...

global___BillingAccountUsageReportEntityData = BillingAccountUsageReportEntityData

@typing.final
class CloudUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a cloud entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    CLOUD_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this cloud."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this cloud."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this cloud."""

    @property
    def cloud(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud:
        """Metadata for the cloud entity."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        cloud: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud", b"cloud", "cost", b"cost", "credit_details", b"credit_details", "expense", b"expense"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud", b"cloud", "cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "periodic", b"periodic"]) -> None: ...

global___CloudUsageReportEntityData = CloudUsageReportEntityData

@typing.final
class FolderUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a folder entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    FOLDER_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this folder."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this folder."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this folder."""

    @property
    def folder(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Folder:
        """Metadata for the folder entity."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        folder: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Folder | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "folder", b"folder"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "folder", b"folder", "periodic", b"periodic"]) -> None: ...

global___FolderUsageReportEntityData = FolderUsageReportEntityData

@typing.final
class ServiceUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a service entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this service."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this service."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this service."""

    @property
    def service(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Service:
        """Metadata for the service entity."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        service: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Service | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "periodic", b"periodic", "service", b"service"]) -> None: ...

global___ServiceUsageReportEntityData = ServiceUsageReportEntityData

@typing.final
class SKUUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a SKU entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    PRICING_QUANTITY_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this entity."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this entity."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this entity."""

    @property
    def pricing_quantity(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total resource usage (pricing quantity) for this entity, measured in pricing units."""

    @property
    def sku(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.SKU:
        """Metadata for a product/SKU entity."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        pricing_quantity: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        sku: yandex.cloud.billing.usage_records.v1.billing_types_pb2.SKU | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "pricing_quantity", b"pricing_quantity", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "periodic", b"periodic", "pricing_quantity", b"pricing_quantity", "sku", b"sku"]) -> None: ...

global___SKUUsageReportEntityData = SKUUsageReportEntityData

@typing.final
class ResourceUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a resource entity in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this label group."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this label group."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this label group."""

    @property
    def resource(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Resource:
        """Metadata for the label-based grouping."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        resource: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Resource | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "periodic", b"periodic", "resource", b"resource"]) -> None: ...

global___ResourceUsageReportEntityData = ResourceUsageReportEntityData

@typing.final
class LabelUsageReportEntityData(google.protobuf.message.Message):
    """Usage and billing data for a label-based entity/grouping in the report.
    This represents the second level in the response structure hierarchy (entity-level totals),
    containing both summary data for the entity across the entire period and a time series breakdown.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    PERIODIC_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total cost associated with this label group."""

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Total credits (discounts, grants, adjustments) applied to this label group."""

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this label group."""

    @property
    def label(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Label:
        """Metadata for the label-based grouping."""

    @property
    def periodic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageReportPeriodicData]:
        """Time series with usage and billing details for each TimeGrouping period (e.g., daily)."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        label: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Label | None = ...,
        periodic: collections.abc.Iterable[global___UsageReportPeriodicData] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "label", b"label", "periodic", b"periodic"]) -> None: ...

global___LabelUsageReportEntityData = LabelUsageReportEntityData

@typing.final
class UsageReportPeriodicData(google.protobuf.message.Message):
    """Represents usage and billing data for a specific aggregation period (e.g., a single day, month).
    This message is part of the third level in the response structure hierarchy, providing the
    time series breakdown for entities. It appears in the 'periodic' field of each entity data object,
    containing financial metrics for each time interval within the requested date range.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COST_FIELD_NUMBER: builtins.int
    CREDIT_DETAILS_FIELD_NUMBER: builtins.int
    EXPENSE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def cost(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Cost incurred during this specific period.
        This is the raw cost before any credits are applied.
        """

    @property
    def credit_details(self) -> yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails:
        """Credits applied during this period.
        Contains a detailed breakdown of all credit types (monetary grants, volume incentives, etc.)
        that were applied during this specific time interval.
        """

    @property
    def expense(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total expense (including cost and credit) for this period.
        This is the final billable amount after all credits have been applied.
        Formula: expense = cost + credit_details.credit
        """

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp indicating the beginning of the TimeGrouping period."""

    def __init__(
        self,
        *,
        cost: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        credit_details: yandex.cloud.billing.usage_records.v1.credit_pb2.CreditDetails | None = ...,
        expense: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cost", b"cost", "credit_details", b"credit_details", "expense", b"expense", "timestamp", b"timestamp"]) -> None: ...

global___UsageReportPeriodicData = UsageReportPeriodicData



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DnsFirewall(google.protobuf.message.Message):
    """A DNS firewall. For details about the concept, see [DNS firewalls](/docs/dns/concepts/dns-firewall)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class ResourceConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _ResourceType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ResourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DnsFirewall.ResourceConfig._ResourceType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            RESOURCE_TYPE_UNSPECIFIED: DnsFirewall.ResourceConfig._ResourceType.ValueType  # 0
            """Unspecified resource type."""
            NETWORK: DnsFirewall.ResourceConfig._ResourceType.ValueType  # 1
            """VPC network resource type."""
            FOLDER: DnsFirewall.ResourceConfig._ResourceType.ValueType  # 2
            """Folder resource type."""
            CLOUD: DnsFirewall.ResourceConfig._ResourceType.ValueType  # 3
            """Cloud resource type."""

        class ResourceType(_ResourceType, metaclass=_ResourceTypeEnumTypeWrapper): ...
        RESOURCE_TYPE_UNSPECIFIED: DnsFirewall.ResourceConfig.ResourceType.ValueType  # 0
        """Unspecified resource type."""
        NETWORK: DnsFirewall.ResourceConfig.ResourceType.ValueType  # 1
        """VPC network resource type."""
        FOLDER: DnsFirewall.ResourceConfig.ResourceType.ValueType  # 2
        """Folder resource type."""
        CLOUD: DnsFirewall.ResourceConfig.ResourceType.ValueType  # 3
        """Cloud resource type."""

        TYPE_FIELD_NUMBER: builtins.int
        RESOURCE_IDS_FIELD_NUMBER: builtins.int
        LOCKING_POLICY_ENABLED_FIELD_NUMBER: builtins.int
        type: global___DnsFirewall.ResourceConfig.ResourceType.ValueType
        """Type of the resource."""
        locking_policy_enabled: builtins.bool
        """Whether the locking policy is enabled."""
        @property
        def resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Resource ids."""

        def __init__(
            self,
            *,
            type: global___DnsFirewall.ResourceConfig.ResourceType.ValueType = ...,
            resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
            locking_policy_enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["locking_policy_enabled", b"locking_policy_enabled", "resource_ids", b"resource_ids", "type", b"type"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_CONFIG_FIELD_NUMBER: builtins.int
    WHITELIST_FQDNS_FIELD_NUMBER: builtins.int
    BLACKLIST_FQDNS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the DNS firewall. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the DNS firewall belongs to."""
    name: builtins.str
    """Name of the DNS firewall.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the DNS firewall."""
    deletion_protection: builtins.bool
    """Prevents accidental firewall removal."""
    enabled: builtins.bool
    """Whether the DNS firewall is enabled."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS firewall labels as `key:value` pairs."""

    @property
    def resource_config(self) -> global___DnsFirewall.ResourceConfig:
        """Resource settings.
        Specifies resources that the DNS firewall applies to.
        """

    @property
    def whitelist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall allows to pass."""

    @property
    def blacklist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall blocks."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        enabled: builtins.bool = ...,
        resource_config: global___DnsFirewall.ResourceConfig | None = ...,
        whitelist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
        blacklist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "resource_config", b"resource_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blacklist_fqdns", b"blacklist_fqdns", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "enabled", b"enabled", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "resource_config", b"resource_config", "whitelist_fqdns", b"whitelist_fqdns"]) -> None: ...

global___DnsFirewall = DnsFirewall



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/mcpgateway/v1/mcp_gateway.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/mcpgateway/v1/mcp_gateway.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/serverless/mcpgateway/v1/mcp_gateway.proto\x12%yandex.cloud.serverless.mcpgateway.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xb5\x05\n\nMcpGateway\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x05tools\x18\x03 \x03(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpTool\x12\x34\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12M\n\x06labels\x18\x07 \x03(\x0b\x32=.yandex.cloud.serverless.mcpgateway.v1.McpGateway.LabelsEntry\x12H\n\x06status\x18\x08 \x01(\x0e\x32\x38.yandex.cloud.serverless.mcpgateway.v1.McpGateway.Status\x12\x13\n\x0b\x62\x61se_domain\x18\t \x01(\t\x12\x46\n\x0blog_options\x18\n \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x12\n\nnetwork_id\x18\x0c \x01(\t\x12\x16\n\x08\x63loud_id\x18\r \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06public\x18\x0e \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x8f\x04\n\x11McpGatewayPreview\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12T\n\x06labels\x18\x06 \x03(\x0b\x32\x44.yandex.cloud.serverless.mcpgateway.v1.McpGatewayPreview.LabelsEntry\x12N\n\x06status\x18\x07 \x01(\x0e\x32\x38.yandex.cloud.serverless.mcpgateway.v1.McpGateway.StatusB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x62\x61se_domain\x18\x08 \x01(\t\x12\x46\n\x0blog_options\x18\t \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x0e\n\x06public\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x16\n\x0clog_group_id\x18\x02 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\"\xd1\x01\n\x07McpTool\x12=\n\x04name\x18\x01 \x01(\tB/\xe8\xc7\x31\x01\xf2\xc7\x31\x1e([a-zA-Z][-a-zA-Z0-9_]{0,63})?\x8a\xc8\x31\x05<=128\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536\x12\x19\n\x11input_json_schema\x18\x03 \x01(\t\x12J\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.serverless.mcpgateway.v1.McpToolActionB\x04\xe8\xc7\x31\x01\"\xdd\x03\n\rMcpToolAction\x12L\n\rfunction_call\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.serverless.mcpgateway.v1.FunctionCallH\x00\x12N\n\x0e\x63ontainer_call\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.mcpgateway.v1.ContainerCallH\x00\x12\x44\n\thttp_call\x18\x03 \x01(\x0b\x32/.yandex.cloud.serverless.mcpgateway.v1.HttpCallH\x00\x12\x42\n\x08mcp_call\x18\x04 \x01(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpCallH\x00\x12\x44\n\tgrpc_call\x18\x05 \x01(\x0b\x32/.yandex.cloud.serverless.mcpgateway.v1.GrpcCallH\x00\x12N\n\x0estart_workflow\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.serverless.mcpgateway.v1.StartWorkflowH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"6\n\x0c\x46unctionCall\x12\x19\n\x0b\x66unction_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\xe2\x03\n\rContainerCall\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x41\n\x06method\x18\x03 \x01(\x0e\x32\x31.yandex.cloud.serverless.mcpgateway.v1.HttpMethod\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12R\n\x07headers\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.serverless.mcpgateway.v1.ContainerCall.HeadersEntry\x12N\n\x05query\x18\x06 \x03(\x0b\x32?.yandex.cloud.serverless.mcpgateway.v1.ContainerCall.QueryEntry\x12T\n\x0f\x66orward_headers\x18\x07 \x01(\x0b\x32;.yandex.cloud.serverless.mcpgateway.v1.ForwardHeadersPolicy\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x03\n\x08HttpCall\x12\x11\n\x03url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x41\n\x06method\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.serverless.mcpgateway.v1.HttpMethod\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12M\n\x07headers\x18\x04 \x03(\x0b\x32<.yandex.cloud.serverless.mcpgateway.v1.HttpCall.HeadersEntry\x12I\n\x05query\x18\x05 \x03(\x0b\x32:.yandex.cloud.serverless.mcpgateway.v1.HttpCall.QueryEntry\x12\x1b\n\x13use_service_account\x18\x06 \x01(\x08\x12T\n\x0f\x66orward_headers\x18\x07 \x01(\x0b\x32;.yandex.cloud.serverless.mcpgateway.v1.ForwardHeadersPolicy\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x01\n\x14\x46orwardHeadersPolicy\x12[\n\x04mode\x18\x01 \x01(\x0e\x32G.yandex.cloud.serverless.mcpgateway.v1.ForwardHeadersPolicy.ForwardModeB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07headers\x18\x02 \x03(\t\"K\n\x0b\x46orwardMode\x12\x1c\n\x18\x46ORWARD_MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nWHITE_LIST\x10\x01\x12\x0e\n\nBLACK_LIST\x10\x02\"\xad\x07\n\x07McpCall\x12\x11\n\x03url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12L\n\ttool_call\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.serverless.mcpgateway.v1.McpCall.ToolCallH\x00\x12K\n\ttransport\x18\x03 \x01(\x0e\x32\x38.yandex.cloud.serverless.mcpgateway.v1.McpCall.Transport\x12V\n\x0cunauthorized\x18\x04 \x01(\x0b\x32>.yandex.cloud.serverless.mcpgateway.v1.McpCall.NoAuthorizationH\x01\x12T\n\x06header\x18\x05 \x01(\x0b\x32\x42.yandex.cloud.serverless.mcpgateway.v1.McpCall.HeaderAuthorizationH\x01\x12Y\n\x0fservice_account\x18\x06 \x01(\x0b\x32>.yandex.cloud.serverless.mcpgateway.v1.McpCall.SaAuthorizationH\x01\x12[\n\x0f\x66orward_headers\x18\x07 \x03(\x0b\x32\x42.yandex.cloud.serverless.mcpgateway.v1.McpCall.ForwardHeadersEntry\x12U\n\x10transfer_headers\x18\x08 \x01(\x0b\x32;.yandex.cloud.serverless.mcpgateway.v1.ForwardHeadersPolicy\x1a\x35\n\x13\x46orwardHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x11\n\x0fNoAuthorization\x1a\x11\n\x0fSaAuthorization\x1a@\n\x13HeaderAuthorization\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x1a<\n\x08ToolCall\x12\x17\n\ttool_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\x0fparameters_json\x18\x02 \x01(\t\"?\n\tTransport\x12\x19\n\x15TRANSPORT_UNSPECIFIED\x10\x00\x12\x07\n\x03SSE\x10\x01\x12\x0e\n\nSTREAMABLE\x10\x02\x42\x08\n\x06\x61\x63tionB\x0f\n\rauthorization\"\xb8\x02\n\x08GrpcCall\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x06method\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\x13use_service_account\x18\x03 \x01(\x08\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12M\n\x07headers\x18\x05 \x03(\x0b\x32<.yandex.cloud.serverless.mcpgateway.v1.GrpcCall.HeadersEntry\x12T\n\x0f\x66orward_headers\x18\x06 \x01(\x0b\x32;.yandex.cloud.serverless.mcpgateway.v1.ForwardHeadersPolicy\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x01\n\rStartWorkflow\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\ninput_json\x18\x02 \x01(\t\x12G\n\x04mode\x18\x03 \x01(\x0e\x32\x39.yandex.cloud.serverless.mcpgateway.v1.StartWorkflow.Mode\"1\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SYNC\x10\x01\x12\t\n\x05\x41SYNC\x10\x02*\x8b\x01\n\nHttpMethod\x12\x1b\n\x17HTTP_METHOD_UNSPECIFIED\x10\x00\x12\x0b\n\x07OPTIONS\x10\x01\x12\x07\n\x03GET\x10\x02\x12\x08\n\x04HEAD\x10\x03\x12\x08\n\x04POST\x10\x04\x12\x07\n\x03PUT\x10\x05\x12\t\n\x05PATCH\x10\x06\x12\n\n\x06\x44\x45LETE\x10\x07\x12\t\n\x05TRACE\x10\x08\x12\x0b\n\x07\x43ONNECT\x10\tB\x81\x01\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.mcpgateway.v1.mcp_gateway_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgateway'
  _globals['_MCPGATEWAY_LABELSENTRY']._loaded_options = None
  _globals['_MCPGATEWAY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MCPGATEWAY'].fields_by_name['id']._loaded_options = None
  _globals['_MCPGATEWAY'].fields_by_name['id']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAY'].fields_by_name['folder_id']._loaded_options = None
  _globals['_MCPGATEWAY'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAY'].fields_by_name['created_at']._loaded_options = None
  _globals['_MCPGATEWAY'].fields_by_name['created_at']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAY'].fields_by_name['name']._loaded_options = None
  _globals['_MCPGATEWAY'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAY'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_MCPGATEWAY'].fields_by_name['cloud_id']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAYPREVIEW_LABELSENTRY']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['id']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['id']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['folder_id']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['created_at']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['created_at']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['name']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['status']._loaded_options = None
  _globals['_MCPGATEWAYPREVIEW'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_MCPTOOL'].fields_by_name['name']._loaded_options = None
  _globals['_MCPTOOL'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\036([a-zA-Z][-a-zA-Z0-9_]{0,63})?\212\3101\005<=128'
  _globals['_MCPTOOL'].fields_by_name['description']._loaded_options = None
  _globals['_MCPTOOL'].fields_by_name['description']._serialized_options = b'\212\3101\007<=65536'
  _globals['_MCPTOOL'].fields_by_name['action']._loaded_options = None
  _globals['_MCPTOOL'].fields_by_name['action']._serialized_options = b'\350\3071\001'
  _globals['_MCPTOOLACTION'].oneofs_by_name['action']._loaded_options = None
  _globals['_MCPTOOLACTION'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_FUNCTIONCALL'].fields_by_name['function_id']._loaded_options = None
  _globals['_FUNCTIONCALL'].fields_by_name['function_id']._serialized_options = b'\350\3071\001'
  _globals['_CONTAINERCALL_HEADERSENTRY']._loaded_options = None
  _globals['_CONTAINERCALL_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERCALL_QUERYENTRY']._loaded_options = None
  _globals['_CONTAINERCALL_QUERYENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERCALL'].fields_by_name['container_id']._loaded_options = None
  _globals['_CONTAINERCALL'].fields_by_name['container_id']._serialized_options = b'\350\3071\001'
  _globals['_HTTPCALL_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPCALL_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPCALL_QUERYENTRY']._loaded_options = None
  _globals['_HTTPCALL_QUERYENTRY']._serialized_options = b'8\001'
  _globals['_HTTPCALL'].fields_by_name['url']._loaded_options = None
  _globals['_HTTPCALL'].fields_by_name['url']._serialized_options = b'\350\3071\001'
  _globals['_FORWARDHEADERSPOLICY'].fields_by_name['mode']._loaded_options = None
  _globals['_FORWARDHEADERSPOLICY'].fields_by_name['mode']._serialized_options = b'\350\3071\001'
  _globals['_MCPCALL_FORWARDHEADERSENTRY']._loaded_options = None
  _globals['_MCPCALL_FORWARDHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_MCPCALL_TOOLCALL'].fields_by_name['tool_name']._loaded_options = None
  _globals['_MCPCALL_TOOLCALL'].fields_by_name['tool_name']._serialized_options = b'\350\3071\001'
  _globals['_MCPCALL'].fields_by_name['url']._loaded_options = None
  _globals['_MCPCALL'].fields_by_name['url']._serialized_options = b'\350\3071\001'
  _globals['_GRPCCALL_HEADERSENTRY']._loaded_options = None
  _globals['_GRPCCALL_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_GRPCCALL'].fields_by_name['endpoint']._loaded_options = None
  _globals['_GRPCCALL'].fields_by_name['endpoint']._serialized_options = b'\350\3071\001'
  _globals['_GRPCCALL'].fields_by_name['method']._loaded_options = None
  _globals['_GRPCCALL'].fields_by_name['method']._serialized_options = b'\350\3071\001'
  _globals['_STARTWORKFLOW'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_STARTWORKFLOW'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_HTTPMETHOD']._serialized_start=4952
  _globals['_HTTPMETHOD']._serialized_end=5091
  _globals['_MCPGATEWAY']._serialized_start=204
  _globals['_MCPGATEWAY']._serialized_end=897
  _globals['_MCPGATEWAY_LABELSENTRY']._serialized_start=753
  _globals['_MCPGATEWAY_LABELSENTRY']._serialized_end=798
  _globals['_MCPGATEWAY_STATUS']._serialized_start=800
  _globals['_MCPGATEWAY_STATUS']._serialized_end=897
  _globals['_MCPGATEWAYPREVIEW']._serialized_start=900
  _globals['_MCPGATEWAYPREVIEW']._serialized_end=1427
  _globals['_MCPGATEWAYPREVIEW_LABELSENTRY']._serialized_start=753
  _globals['_MCPGATEWAYPREVIEW_LABELSENTRY']._serialized_end=798
  _globals['_LOGOPTIONS']._serialized_start=1430
  _globals['_LOGOPTIONS']._serialized_end=1580
  _globals['_MCPTOOL']._serialized_start=1583
  _globals['_MCPTOOL']._serialized_end=1792
  _globals['_MCPTOOLACTION']._serialized_start=1795
  _globals['_MCPTOOLACTION']._serialized_end=2272
  _globals['_FUNCTIONCALL']._serialized_start=2274
  _globals['_FUNCTIONCALL']._serialized_end=2328
  _globals['_CONTAINERCALL']._serialized_start=2331
  _globals['_CONTAINERCALL']._serialized_end=2813
  _globals['_CONTAINERCALL_HEADERSENTRY']._serialized_start=2721
  _globals['_CONTAINERCALL_HEADERSENTRY']._serialized_end=2767
  _globals['_CONTAINERCALL_QUERYENTRY']._serialized_start=2769
  _globals['_CONTAINERCALL_QUERYENTRY']._serialized_end=2813
  _globals['_HTTPCALL']._serialized_start=2816
  _globals['_HTTPCALL']._serialized_end=3289
  _globals['_HTTPCALL_HEADERSENTRY']._serialized_start=2721
  _globals['_HTTPCALL_HEADERSENTRY']._serialized_end=2767
  _globals['_HTTPCALL_QUERYENTRY']._serialized_start=2769
  _globals['_HTTPCALL_QUERYENTRY']._serialized_end=2813
  _globals['_FORWARDHEADERSPOLICY']._serialized_start=3292
  _globals['_FORWARDHEADERSPOLICY']._serialized_end=3501
  _globals['_FORWARDHEADERSPOLICY_FORWARDMODE']._serialized_start=3426
  _globals['_FORWARDHEADERSPOLICY_FORWARDMODE']._serialized_end=3501
  _globals['_MCPCALL']._serialized_start=3504
  _globals['_MCPCALL']._serialized_end=4445
  _globals['_MCPCALL_FORWARDHEADERSENTRY']._serialized_start=4134
  _globals['_MCPCALL_FORWARDHEADERSENTRY']._serialized_end=4187
  _globals['_MCPCALL_NOAUTHORIZATION']._serialized_start=4189
  _globals['_MCPCALL_NOAUTHORIZATION']._serialized_end=4206
  _globals['_MCPCALL_SAAUTHORIZATION']._serialized_start=4208
  _globals['_MCPCALL_SAAUTHORIZATION']._serialized_end=4225
  _globals['_MCPCALL_HEADERAUTHORIZATION']._serialized_start=4227
  _globals['_MCPCALL_HEADERAUTHORIZATION']._serialized_end=4291
  _globals['_MCPCALL_TOOLCALL']._serialized_start=4293
  _globals['_MCPCALL_TOOLCALL']._serialized_end=4353
  _globals['_MCPCALL_TRANSPORT']._serialized_start=4355
  _globals['_MCPCALL_TRANSPORT']._serialized_end=4418
  _globals['_GRPCCALL']._serialized_start=4448
  _globals['_GRPCCALL']._serialized_end=4760
  _globals['_GRPCCALL_HEADERSENTRY']._serialized_start=2721
  _globals['_GRPCCALL_HEADERSENTRY']._serialized_end=2767
  _globals['_STARTWORKFLOW']._serialized_start=4763
  _globals['_STARTWORKFLOW']._serialized_end=4949
  _globals['_STARTWORKFLOW_MODE']._serialized_start=4900
  _globals['_STARTWORKFLOW_MODE']._serialized_end=4949
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnPremiseMysql(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    port: builtins.int
    """Port for the database connection"""
    subnet_id: builtins.str
    """Identifier of the Yandex Cloud VPC subnetwork to user for accessing the
    database.
    If omitted, the server has to be accessible via Internet
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of host names of the MySQL server. Exactly one host is expected"""

    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode:
        """TLS settings for server connection. Disabled by default."""

    def __init__(
        self,
        *,
        port: builtins.int = ...,
        subnet_id: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "port", b"port", "subnet_id", b"subnet_id", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseMysql = OnPremiseMysql

@typing.final
class MysqlConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_CONNECTION_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    """Managed Service for MySQL cluster ID"""
    @property
    def on_premise(self) -> global___OnPremiseMysql:
        """Connection options for on-premise MySQL"""

    @property
    def connection_manager_connection(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.ConnectionManagerConnection:
        """Get Mysql installation params and credentials from Connection Manager"""

    def __init__(
        self,
        *,
        mdb_cluster_id: builtins.str = ...,
        on_premise: global___OnPremiseMysql | None = ...,
        connection_manager_connection: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ConnectionManagerConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "connection_manager_connection", b"connection_manager_connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "connection_manager_connection", b"connection_manager_connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["mdb_cluster_id", "on_premise", "connection_manager_connection"] | None: ...

global___MysqlConnection = MysqlConnection

@typing.final
class MysqlObjectTransferSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    ROUTINE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Views

    CREATE VIEW ...
    """
    routine: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Routines

    CREATE PROCEDURE ... ; CREATE FUNCTION ... ;
    """
    trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Triggers

    CREATE TRIGGER ...
    """
    tables: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    def __init__(
        self,
        *,
        view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        routine: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        tables: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routine", b"routine", "tables", b"tables", "trigger", b"trigger", "view", b"view"]) -> None: ...

global___MysqlObjectTransferSettings = MysqlObjectTransferSettings

@typing.final
class MysqlSource(google.protobuf.message.Message):
    """Settings specific to the MySQL source endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    OBJECT_TRANSFER_SETTINGS_FIELD_NUMBER: builtins.int
    INCLUDE_TABLES_REGEX_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_REGEX_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SERVICE_DATABASE_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Name of the database to transfer

    You can leave it empty, then it will be possible to transfer tables from several
    databases at the same time from this source.
    """
    user: builtins.str
    """User for database access. Required unless connection manager connection is used"""
    timezone: builtins.str
    """Database timezone

    Is used for parsing timestamps for saving source timezones. Accepts values from
    IANA timezone database. Default: local timezone.
    """
    service_database: builtins.str
    """Database for service tables
    Default: data source database. Here created technical tables (__tm_keeper,
    __tm_gtid_keeper).
    """
    @property
    def connection(self) -> global___MysqlConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def object_transfer_settings(self) -> global___MysqlObjectTransferSettings:
        """Schema migration
        Defines which database schema objects should be transferred, e.g. views,
        routines, etc. 
        All of the attrubutes in the block are optional and should be either
        `BEFORE_DATA`, `AFTER_DATA` or `NEVER`."
        """

    @property
    def include_tables_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of regular expressions of table names which should be transferred. A table
        name is formatted as schemaname.tablename. For example, a single regular
        expression may look like `^mydb.employees$`
        """

    @property
    def exclude_tables_regex(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Opposite of `include_table_regex`. The tables matching the specified regular
        expressions will not be transferred
        """

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of security groups that the transfer associated with this endpoint should
        use
        """

    def __init__(
        self,
        *,
        connection: global___MysqlConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        timezone: builtins.str = ...,
        object_transfer_settings: global___MysqlObjectTransferSettings | None = ...,
        include_tables_regex: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables_regex: collections.abc.Iterable[builtins.str] | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        service_database: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "object_transfer_settings", b"object_transfer_settings", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "database", b"database", "exclude_tables_regex", b"exclude_tables_regex", "include_tables_regex", b"include_tables_regex", "object_transfer_settings", b"object_transfer_settings", "password", b"password", "security_groups", b"security_groups", "service_database", b"service_database", "timezone", b"timezone", "user", b"user"]) -> None: ...

global___MysqlSource = MysqlSource

@typing.final
class MysqlTarget(google.protobuf.message.Message):
    """Settings specific to the MySQL target endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SQL_MODE_FIELD_NUMBER: builtins.int
    SKIP_CONSTRAINT_CHECKS_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SERVICE_DATABASE_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    IS_SCHEMA_MIGRATION_DISABLED_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name

    Allowed to leave it empty, then the tables will be created in databases with the
    same names as on the source. If this field is empty, then you must fill below db
    schema for service table.
    """
    user: builtins.str
    """User for database access. Required unless connection manager connection is used"""
    sql_mode: builtins.str
    """[sql_mode](https://dev.mysql.com/doc/refman/5.7/en/sql-mode.html) to use when
    interacting with the server. 
    Defaults to `NO_AUTO_VALUE_ON_ZERO,NO_DIR_IN_CREATE,NO_ENGINE_SUBSTITUTION`
    """
    skip_constraint_checks: builtins.bool
    """Disable constraints checks
    When `true`, disables foreign key checks and unique checks. `False` by default.
    See
    [foreign_key_checks](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_foreign_key_checks).
    Recommend to disable for increase replication speed unless schema contains
    cascading operations
    """
    timezone: builtins.str
    """Database timezone

    Is used for parsing timestamps for saving source timezones. Accepts values from
    IANA timezone database. Default: local timezone.
    """
    cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType
    """Cleanup policy for activate, reactivate and reupload processes.  
    One of `DISABLED`, `DROP` or `TRUNCATE` Default is `DISABLED`.
    """
    service_database: builtins.str
    """Database schema for service table
    Default: db name. Here created technical tables (__tm_keeper, __tm_gtid_keeper).
    """
    is_schema_migration_disabled: builtins.bool
    """Whether can change table schema if schema changed on source"""
    @property
    def connection(self) -> global___MysqlConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of security groups that the transfer associated with this endpoint should
        use
        """

    def __init__(
        self,
        *,
        connection: global___MysqlConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        sql_mode: builtins.str = ...,
        skip_constraint_checks: builtins.bool = ...,
        timezone: builtins.str = ...,
        cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType = ...,
        service_database: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_schema_migration_disabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "connection", b"connection", "database", b"database", "is_schema_migration_disabled", b"is_schema_migration_disabled", "password", b"password", "security_groups", b"security_groups", "service_database", b"service_database", "skip_constraint_checks", b"skip_constraint_checks", "sql_mode", b"sql_mode", "timezone", b"timezone", "user", b"user"]) -> None: ...

global___MysqlTarget = MysqlTarget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/billing_types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/billing_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/billing/usage_records/v1/billing_types.proto\x12%yandex.cloud.billing.usage_records.v1\"\x1b\n\tLabelList\x12\x0e\n\x06values\x18\x01 \x03(\t\"*\n\x0e\x42illingAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"!\n\x05\x43loud\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n\x06\x46older\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"8\n\x07Service\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"y\n\x03SKU\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eru_translation\x18\x03 \x01(\t\x12\x16\n\x0e\x65n_translation\x18\x04 \x01(\t\x12\x14\n\x0cpricing_unit\x18\x05 \x01(\t\x12\x12\n\nservice_id\x18\x06 \x01(\t\"\x16\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\"#\n\x05Label\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.billing_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_LABELLIST']._serialized_start=100
  _globals['_LABELLIST']._serialized_end=127
  _globals['_BILLINGACCOUNT']._serialized_start=129
  _globals['_BILLINGACCOUNT']._serialized_end=171
  _globals['_CLOUD']._serialized_start=173
  _globals['_CLOUD']._serialized_end=206
  _globals['_FOLDER']._serialized_start=208
  _globals['_FOLDER']._serialized_end=242
  _globals['_SERVICE']._serialized_start=244
  _globals['_SERVICE']._serialized_end=300
  _globals['_SKU']._serialized_start=302
  _globals['_SKU']._serialized_end=423
  _globals['_RESOURCE']._serialized_start=425
  _globals['_RESOURCE']._serialized_end=447
  _globals['_LABEL']._serialized_start=449
  _globals['_LABEL']._serialized_end=484
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_firewall_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_firewall_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.dns.v1 import dns_firewall_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__firewall__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/dns/v1/dns_firewall_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/dns/v1/dns_firewall.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetDnsFirewallRequest\x12\x1d\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x17ListDnsFirewallsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"l\n\x18ListDnsFirewallsResponse\x12\x37\n\rdns_firewalls\x18\x01 \x03(\x0b\x32 .yandex.cloud.dns.v1.DnsFirewall\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa9\x04\n\x18\x43reateDnsFirewallRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.dns.v1.CreateDnsFirewallRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12H\n\x0fresource_config\x18\x07 \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\x08 \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\t \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19\x43reateDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"\xda\x04\n\x18UpdateDnsFirewallRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.dns.v1.UpdateDnsFirewallRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12H\n\x0fresource_config\x18\x08 \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\t \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\n \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"j\n\x16MoveDnsFirewallRequest\x12#\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x32\x30\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x17MoveDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\";\n\x18\x44\x65leteDnsFirewallRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\"4\n\x19\x44\x65leteDnsFirewallMetadata\x12\x17\n\x0f\x64ns_firewall_id\x18\x01 \x01(\t\"\x9e\x01\n ListDnsFirewallOperationsRequest\x12\x1f\n\x0f\x64ns_firewall_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"s\n!ListDnsFirewallOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xaf\x0e\n\x12\x44nsFirewallService\x12\x80\x01\n\x03Get\x12*.yandex.cloud.dns.v1.GetDnsFirewallRequest\x1a .yandex.cloud.dns.v1.DnsFirewall\"+\x82\xd3\xe4\x93\x02%\x12#/dns/v1/firewalls/{dns_firewall_id}\x12~\n\x04List\x12,.yandex.cloud.dns.v1.ListDnsFirewallsRequest\x1a-.yandex.cloud.dns.v1.ListDnsFirewallsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/dns/v1/firewalls\x12\xa4\x01\n\x06\x43reate\x12-.yandex.cloud.dns.v1.CreateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*(\n\x19\x43reateDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02\x16\"\x11/dns/v1/firewalls:\x01*\x12\xb6\x01\n\x06Update\x12-.yandex.cloud.dns.v1.UpdateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*(\n\x19UpdateDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02(2#/dns/v1/firewalls/{dns_firewall_id}:\x01*\x12\xb5\x01\n\x04Move\x12+.yandex.cloud.dns.v1.MoveDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*&\n\x17MoveDnsFirewallMetadata\x12\x0b\x44nsFirewall\x82\xd3\xe4\x93\x02-\"(/dns/v1/firewalls/{dns_firewall_id}:move:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12-.yandex.cloud.dns.v1.DeleteDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*2\n\x19\x44\x65leteDnsFirewallMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/dns/v1/firewalls/{dns_firewall_id}\x12\xb7\x01\n\x0eListOperations\x12\x35.yandex.cloud.dns.v1.ListDnsFirewallOperationsRequest\x1a\x36.yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dns/v1/firewalls/{dns_firewall_id}/operations\x12\xb1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/dns/v1/firewalls/{resource_id}:listAccessBindings\x12\xe0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36\"1/dns/v1/firewalls/{resource_id}:setAccessBindings:\x01*\x12\xec\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/dns/v1/firewalls/{resource_id}:updateAccessBindings:\x01*BV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_firewall_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_GETDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_GETDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSFIREWALLSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_CREATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_UPDATEDNSFIREWALLREQUEST'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\350\3071\001\212\3101\00220'
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVEDNSFIREWALLREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_DELETEDNSFIREWALLREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['dns_firewall_id']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['dns_firewall_id']._serialized_options = b'\212\3101\00220'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/dns/v1/firewalls/{dns_firewall_id}'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/dns/v1/firewalls'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002\026\"\021/dns/v1/firewalls:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002(2#/dns/v1/firewalls/{dns_firewall_id}:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*&\n\027MoveDnsFirewallMetadata\022\013DnsFirewall\202\323\344\223\002-\"(/dns/v1/firewalls/{dns_firewall_id}:move:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteDnsFirewallMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/dns/v1/firewalls/{dns_firewall_id}'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0020\022./dns/v1/firewalls/{dns_firewall_id}/operations'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0024\0222/dns/v1/firewalls/{resource_id}:listAccessBindings'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0026\"1/dns/v1/firewalls/{resource_id}:setAccessBindings:\001*'
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_DNSFIREWALLSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/dns/v1/firewalls/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETDNSFIREWALLREQUEST']._serialized_start=314
  _globals['_GETDNSFIREWALLREQUEST']._serialized_end=368
  _globals['_LISTDNSFIREWALLSREQUEST']._serialized_start=371
  _globals['_LISTDNSFIREWALLSREQUEST']._serialized_end=512
  _globals['_LISTDNSFIREWALLSRESPONSE']._serialized_start=514
  _globals['_LISTDNSFIREWALLSRESPONSE']._serialized_end=622
  _globals['_CREATEDNSFIREWALLREQUEST']._serialized_start=625
  _globals['_CREATEDNSFIREWALLREQUEST']._serialized_end=1178
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_start=1133
  _globals['_CREATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_end=1178
  _globals['_CREATEDNSFIREWALLMETADATA']._serialized_start=1180
  _globals['_CREATEDNSFIREWALLMETADATA']._serialized_end=1232
  _globals['_UPDATEDNSFIREWALLREQUEST']._serialized_start=1235
  _globals['_UPDATEDNSFIREWALLREQUEST']._serialized_end=1837
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_start=1133
  _globals['_UPDATEDNSFIREWALLREQUEST_LABELSENTRY']._serialized_end=1178
  _globals['_UPDATEDNSFIREWALLMETADATA']._serialized_start=1839
  _globals['_UPDATEDNSFIREWALLMETADATA']._serialized_end=1891
  _globals['_MOVEDNSFIREWALLREQUEST']._serialized_start=1893
  _globals['_MOVEDNSFIREWALLREQUEST']._serialized_end=1999
  _globals['_MOVEDNSFIREWALLMETADATA']._serialized_start=2001
  _globals['_MOVEDNSFIREWALLMETADATA']._serialized_end=2051
  _globals['_DELETEDNSFIREWALLREQUEST']._serialized_start=2053
  _globals['_DELETEDNSFIREWALLREQUEST']._serialized_end=2112
  _globals['_DELETEDNSFIREWALLMETADATA']._serialized_start=2114
  _globals['_DELETEDNSFIREWALLMETADATA']._serialized_end=2166
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST']._serialized_start=2169
  _globals['_LISTDNSFIREWALLOPERATIONSREQUEST']._serialized_end=2327
  _globals['_LISTDNSFIREWALLOPERATIONSRESPONSE']._serialized_start=2329
  _globals['_LISTDNSFIREWALLOPERATIONSRESPONSE']._serialized_end=2444
  _globals['_DNSFIREWALLSERVICE']._serialized_start=2447
  _globals['_DNSFIREWALLSERVICE']._serialized_end=4286
# @@protoc_insertion_point(module_scope)
